package com.landray.kmss.sys.attachment.integrate.wps.authen;

import com.landray.kmss.sys.authentication.ssoclient.redis.RedisPoolUtil;
import java.util.Calendar;
import java.util.TimeZone;
import com.landray.kmss.sys.cache.redis.RedisConfig;
import com.landray.kmss.sys.authentication.ssoclient.SsoConfigUtil;
import java.io.Serializable;

public class WpsOfficeToken implements Serializable
{
    private static final long serialVersionUID = -2615720574536845559L;
    private long createTime;
    private long expireTime;
    private String tokenString;
    private String username;
    
    protected WpsOfficeToken(final long expireTime, final String username, final String tokenString) {
        this.expireTime = expireTime;
        this.username = username;
        this.tokenString = tokenString;
    }
    
    protected WpsOfficeToken(final long createTime, final long expireTime, final String username, final String tokenString) {
        this.createTime = createTime;
        this.expireTime = expireTime;
        this.username = username;
        this.tokenString = tokenString;
    }
    
    @Override
    public boolean equals(final Object obj) {
        if (obj == null) {
            return false;
        }
        if (obj instanceof String) {
            return obj.equals(this.tokenString);
        }
        return obj instanceof WpsOfficeToken && this.tokenString.equals(((WpsOfficeToken)obj).tokenString);
    }
    
    @Override
    public int hashCode() {
        return this.tokenString.hashCode();
    }
    
    public String getUsername() {
        return this.username;
    }
    
    public boolean isExpired() {
        final Integer maxAgeRedis = SsoConfigUtil.getCookieMaxageRedis();
        if (!RedisConfig.ENABLED || maxAgeRedis == null) {
            return this.isExpiredInCookie();
        }
        return this.isExpired(maxAgeRedis);
    }
    
    public boolean isExpiredInCookie() {
        final Calendar cal = Calendar.getInstance(TimeZone.getTimeZone("GMT0"));
        return cal.getTimeInMillis() > this.expireTime;
    }
    
    public boolean isExpired(final Integer maxAgeRedis) {
        final String expire_redis_str = RedisPoolUtil.get(this.tokenString);
        final Calendar cal = Calendar.getInstance(TimeZone.getTimeZone("GMT0"));
        if (expire_redis_str == null) {
            final boolean isExpired = this.isExpiredInCookie();
            if (!isExpired) {
                final Long expire = cal.getTimeInMillis() + maxAgeRedis * 1000;
                RedisPoolUtil.setEx(this.tokenString, new StringBuilder().append(expire).toString(), SsoConfigUtil.getCookieMaxage() + 100);
            }
            return isExpired;
        }
        final Long expire_redis = Long.parseLong(expire_redis_str);
        final boolean isExpired2 = cal.getTimeInMillis() > expire_redis;
        if (!isExpired2) {
            final Long expire2 = cal.getTimeInMillis() + maxAgeRedis * 1000;
            RedisPoolUtil.setEx(this.tokenString, new StringBuilder().append(expire2).toString(), SsoConfigUtil.getCookieMaxage() + 100);
        }
        return isExpired2;
    }
    
    public long getExpireTime() {
        return this.expireTime;
    }
    
    public long getCreateTime() {
        return this.createTime;
    }
    
    @Override
    public String toString() {
        return this.tokenString;
    }
    
    public String getTokenString() {
        return this.tokenString;
    }
}
